@@ -177,7 +177,7 @@ def extract_features(
     return doc_features
 
 
-_CRFCUT_DATA_FILENAME = "sentenceseg-crfcut-v2.model"
+_CRFCUT_DATA_FILENAME = "sentenceseg_crfcut.model"
 _tagger = pycrfsuite.Tagger()
 _tagger.open(os.path.join(corpus_path(), _CRFCUT_DATA_FILENAME))
 
