@@ -7,9 +7,12 @@ from pythainlp.corpus import (
     conceptnet,
     countries,
     download,
+    get_corpus_db,
     get_corpus_db_detail,
+    get_corpus_path,
     provinces,
     remove,
+    thai_family_names,
     thai_female_names,
     thai_male_names,
     thai_negations,
@@ -20,6 +23,7 @@ from pythainlp.corpus import (
     ttc,
     wordnet,
 )
+from requests import Response
 
 
 class TestCorpusPackage(unittest.TestCase):
@@ -34,12 +38,25 @@ class TestCorpusPackage(unittest.TestCase):
 
         self.assertIsInstance(countries(), frozenset)
         self.assertIsInstance(provinces(), frozenset)
+        self.assertIsInstance(provinces(details=True), list)
+        self.assertEqual(
+            len(provinces(details=False)), len(provinces(details=True))
+        )
+        self.assertIsInstance(thai_family_names(), frozenset)
+        self.assertIsInstance(list(thai_family_names())[0], str)
         self.assertIsInstance(thai_female_names(), frozenset)
         self.assertIsInstance(thai_male_names(), frozenset)
 
+        self.assertIsInstance(
+            get_corpus_db("https://example.com/XXXXXX0lkjasd/SXfmskdjKKXXX"),
+            Response,
+        )  # URL does not exist, should get 404 response
+        self.assertIsNone(get_corpus_db("XXXlkja3sfdXX"))  # Invalid URL
+
         self.assertEqual(
-            get_corpus_db_detail("XXX"), {}
+            get_corpus_db_detail("XXXmx3KSXX"), {}
         )  # corpus does not exist
+
         self.assertTrue(download("test"))  # download the first time
         self.assertTrue(download(name="test", force=True))  # force download
         self.assertTrue(download(name="test"))  # try download existing
@@ -50,8 +67,10 @@ class TestCorpusPackage(unittest.TestCase):
             download(name="XxxXXxxx817d37sf")
         )  # corpus name not exist
         self.assertIsNotNone(get_corpus_db_detail("test"))  # corpus exists
+        self.assertIsNotNone(get_corpus_path("test"))  # corpus exists
         self.assertTrue(remove("test"))  # remove existing
         self.assertFalse(remove("test"))  # remove non-existing
+        self.assertIsNone(get_corpus_path("XXXkdjfBzc"))  # query non-existing
         self.assertTrue(download(name="test", version="0.1"))
         self.assertTrue(remove("test"))
 
